@@ -8,7 +8,10 @@ from dxi.branch.dxi_branch import DXIBranch
 from dxi.branch.dxi_branch import DXIBranchConstants
 
 
-@click.group()
+@click.group(
+    short_help="\b\nPerform Delphix Self-Service Branch Operations.\n"
+               "[create | activate | delete | list] "
+)
 def branch():
     """
     Self-Service Branch operations
@@ -18,20 +21,26 @@ def branch():
 
 @branch.command()
 @click.option(
-    "--engine",
-    default=DXIBranchConstants.ENGINE_ID,
-    help="Name of the engine to run this operation on",
+    "--branch-name", required=True, help="Name of the self-service branch."
 )
 @click.option(
-    "--single_thread",
-    help="Run as a single thread",
+    "--engine",
+    default=DXIBranchConstants.ENGINE_ID,
+    help="\b\nName of Delphix Engine in the config file.\n"
+    "[Default: default]",
+)
+@click.option(
+    "--single-thread",
+    help="\b\nRun as a single thread\n"
+    "[Default: {}]".format(DXIBranchConstants.SINGLE_THREAD),
     default=DXIBranchConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     type=click.INT,
-    help="The number of seconds to wait between job polls.",
+    help="\b\nThe number of seconds to wait between job polls.\n"
+    "[Default: {}s]".format(DXIBranchConstants.POLL),
     default=DXIBranchConstants.POLL,
 )
 @click.option(
@@ -46,18 +55,15 @@ def branch():
     default=DXIBranchConstants.CONFIG,
 )
 @click.option(
-    "--log_file_path",
+    "--log-file-path",
     help="The path to the logfile you want to use.",
     default=DXIBranchConstants.LOG_FILE_PATH,
 )
-@click.option(
-    "--branchname", required=True, help="Name of the branch to delete"
-)
 def delete(
-    engine, single_thread, parallel, poll, config, log_file_path, branchname
+    engine, single_thread, parallel, poll, config, log_file_path, branch_name
 ):
     """
-    Delete a branch by name
+    Delete a self-service branch.
     """
     env_obj = DXIBranch(
         engine=engine,
@@ -67,33 +73,36 @@ def delete(
         log_file_path=log_file_path,
         single_thread=single_thread,
     )
-    boolean_based_system_exit(env_obj.delete(branch_name=branchname))
+    boolean_based_system_exit(env_obj.delete(branch_name=branch_name))
 
 
 @branch.command()
 @click.option(
-    "--branchname", required=True, help="Name of the branch to activate"
+    "--branch-name", required=True, help="Name of the self-service branch."
 )
 @click.option(
-    "--containername",
+    "--container-name",
     required=True,
-    help="Name of the parent container for the branch",
+    help="Name of the parent self-service container for the branch.",
 )
 @click.option(
     "--engine",
     default=DXIBranchConstants.ENGINE_ID,
-    help="Name of the engine to run this operation on",
+    help="\b\nName of Delphix Engine in the config file.\n"
+    "[Default: default]",
 )
 @click.option(
-    "--single_thread",
-    help="Run as a single thread",
+    "--single-thread",
+    help="\b\nRun as a single thread\n"
+    "[Default: {}]".format(DXIBranchConstants.SINGLE_THREAD),
     default=DXIBranchConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     type=click.INT,
-    help="The number of seconds to wait between job polls.",
+    help="\b\nThe number of seconds to wait between job polls.\n"
+    "[Default: {}s]".format(DXIBranchConstants.POLL),
     default=DXIBranchConstants.POLL,
 )
 @click.option(
@@ -108,7 +117,7 @@ def delete(
     default=DXIBranchConstants.CONFIG,
 )
 @click.option(
-    "--log_file_path",
+    "--log-file-path",
     help="The path to the logfile you want to use.",
     default=DXIBranchConstants.LOG_FILE_PATH,
 )
@@ -119,11 +128,11 @@ def activate(
     poll,
     config,
     log_file_path,
-    branchname,
-    containername,
+    branch_name,
+    container_name,
 ):
     """
-    Activate a branch by name
+    Activate a self-service branch.
     """
     env_obj = DXIBranch(
         engine=engine,
@@ -134,7 +143,9 @@ def activate(
         single_thread=single_thread,
     )
     boolean_based_system_exit(
-        env_obj.activate(branch_name=branchname, container_name=containername)
+        env_obj.activate(
+            branch_name=branch_name, container_name=container_name
+        )
     )
 
 
@@ -142,18 +153,21 @@ def activate(
 @click.option(
     "--engine",
     default=DXIBranchConstants.ENGINE_ID,
-    help="Name of the engine to run this operation on",
+    help="\b\nName of Delphix Engine in the config file.\n"
+    "[Default: default]",
 )
 @click.option(
-    "--single_thread",
-    help="Run as a single thread",
+    "--single-thread",
+    help="\b\nRun as a single thread\n"
+    "[Default: {}]".format(DXIBranchConstants.SINGLE_THREAD),
     default=DXIBranchConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     type=click.INT,
-    help="The number of seconds to wait between job polls.",
+    help="\b\nThe number of seconds to wait between job polls.\n"
+    "[Default: {}s]".format(DXIBranchConstants.POLL),
     default=DXIBranchConstants.POLL,
 )
 @click.option(
@@ -168,13 +182,13 @@ def activate(
     default=DXIBranchConstants.CONFIG,
 )
 @click.option(
-    "--log_file_path",
+    "--log-file-path",
     help="The path to the logfile you want to use.",
     default=DXIBranchConstants.LOG_FILE_PATH,
 )
 def list(engine, single_thread, parallel, poll, config, log_file_path):
     """
-    List all branches on an engine
+    List all self-service branches on an engine
     """
     env_obj = DXIBranch(
         engine=engine,
@@ -189,38 +203,50 @@ def list(engine, single_thread, parallel, poll, config, log_file_path):
 
 @branch.command()
 @click.option(
-    "--branchname", default=None, required=True, help="Name of the Branch"
-)
-@click.option(
-    "--containername",
+    "--branch-name",
     default=None,
     required=True,
-    help="Name of the Self Service Container",
+    help="Name of the self-service branch.",
 )
 @click.option(
-    "--templatename", default=None, help="Name of the Self Service Template"
-)
-@click.option(
-    "--bookmarkname",
+    "--container-name",
     default=None,
-    help="Name of the bookmark to create the branch",
+    required=True,
+    help="Name of the parent self-service container.",
 )
 @click.option(
-    "--timestamp", default=None, help="Timestamp to create the branch"
+    "--template-name",
+    default=None,
+    help="Name of the parent self-service template.",
 )
 @click.option(
-    "--engine", help="Name of the engine", default=DXIBranchConstants.ENGINE_ID
+    "--bookmark-name",
+    default=None,
+    help="Name of the self-service bookmark to create the branch.",
 )
 @click.option(
-    "--single_thread",
-    help="Run as a single thread",
+    "--timestamp",
+    default=None,
+    help="Timestamp from the container's timeline to create the branch",
+)
+@click.option(
+    "--engine",
+    default=DXIBranchConstants.ENGINE_ID,
+    help="\b\nName of Delphix Engine in the config file.\n"
+    "[Default: default]",
+)
+@click.option(
+    "--single-thread",
+    help="\b\nRun as a single thread\n"
+    "[Default: {}]".format(DXIBranchConstants.SINGLE_THREAD),
     default=DXIBranchConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     type=click.INT,
-    help="The number of seconds to wait between job polls.",
+    help="\b\nThe number of seconds to wait between job polls.\n"
+    "[Default: {}s]".format(DXIBranchConstants.POLL),
     default=DXIBranchConstants.POLL,
 )
 @click.option(
@@ -235,15 +261,15 @@ def list(engine, single_thread, parallel, poll, config, log_file_path):
     default=DXIBranchConstants.CONFIG,
 )
 @click.option(
-    "--log_file_path",
+    "--log-file-path",
     help="The path to the logfile you want to use.",
     default=DXIBranchConstants.LOG_FILE_PATH,
 )
 def create(
-    branchname,
-    containername,
-    templatename,
-    bookmarkname,
+    branch_name,
+    container_name,
+    template_name,
+    bookmark_name,
     timestamp,
     engine,
     single_thread,
@@ -253,7 +279,7 @@ def create(
     log_file_path,
 ):
     """
-    Create a new Branch
+    Create a new self-service branch.
     """
     env_obj = DXIBranch(
         engine=engine,
@@ -265,10 +291,10 @@ def create(
     )
     boolean_based_system_exit(
         env_obj.create(
-            branch_name=branchname,
-            container_name=containername,
-            template_name=templatename,
-            bookmark_name=bookmarkname,
+            branch_name=branch_name,
+            container_name=container_name,
+            template_name=template_name,
+            bookmark_name=bookmark_name,
             timestamp=timestamp,
         )
     )
