@@ -69,8 +69,7 @@ def run_job(main_func, dx_obj, engine="default", single_thread=True):
             t = main_func(engine_ref, dx_obj, single_thread)
             threads.append(t)
             dx_logging.print_info(
-                f"Executing on Delphix Engine: "
-                f'{engine_ref["hostname"]}'
+                f"Executing on Delphix Engine: " f'{engine_ref["hostname"]}'
             )
         except (exceptions.RequestError, KeyError):
             raise dlpx_exceptions.DlpxException(
@@ -84,7 +83,17 @@ def run_job(main_func, dx_obj, engine="default", single_thread=True):
     return threads
 
 
-def run_job_mt(main_func, dx_obj, engine="default", single_thread=True):
+def _get_thread(main_func, engine, dx_obj, single_thread, helper_ref):
+    if helper_ref:
+        t = main_func(engine, dx_obj, single_thread, helper_ref)
+    else:
+        t = main_func(engine, dx_obj, single_thread)
+    return t
+
+
+def run_job_mt(
+    main_func, dx_obj, engine="default", single_thread=True, helper_ref=None
+):
     """
     This method runs the main_func asynchronously against all the
     delphix engines specified
@@ -107,8 +116,9 @@ def run_job_mt(main_func, dx_obj, engine="default", single_thread=True):
             for delphix_ddp in dx_obj.dlpx_ddps:
                 engine_ref = dx_obj.dlpx_ddps[delphix_ddp]
                 dx_obj.jobs[engine_ref["ip_address"]] = []
-                t = main_func(
-                    dx_obj.dlpx_ddps[delphix_ddp], dx_obj, single_thread
+
+                t = _get_thread(
+                    main_func, engine_ref, dx_obj, single_thread, helper_ref
                 )
                 threads.append(t)
                 # TODO: Revisit threading logic
@@ -134,8 +144,12 @@ def run_job_mt(main_func, dx_obj, engine="default", single_thread=True):
                     dx_logging.print_info(
                         f"Executing on the default Delphix Engine"
                     )
-                    t = main_func(
-                        dx_obj.dlpx_ddps[delphix_ddp], dx_obj, single_thread
+                    t = _get_thread(
+                        main_func,
+                        engine_ref,
+                        dx_obj,
+                        single_thread,
+                        helper_ref,
                     )
                     threads.append(t)
                     break
@@ -149,11 +163,12 @@ def run_job_mt(main_func, dx_obj, engine="default", single_thread=True):
         try:
             engine_ref = dx_obj.dlpx_ddps[engine]
             dx_obj.jobs[engine_ref["ip_address"]] = []
-            t = main_func(engine_ref, dx_obj, single_thread)
+            t = _get_thread(
+                main_func, engine_ref, dx_obj, single_thread, helper_ref
+            )
             threads.append(t)
             dx_logging.print_info(
-                f"Executing on Delphix Engine: "
-                f'{engine_ref["hostname"]}'
+                f"Executing on Delphix Engine: " f'{engine_ref["hostname"]}'
             )
         except (exceptions.RequestError, KeyError):
             raise dlpx_exceptions.DlpxException(
@@ -193,9 +208,7 @@ def track_running_jobs(
             f'No running jobs on engine : {engine["hostname"]}'
         )
     else:
-        dx_logging.print_info(
-            f'Waiting for jobs on : {engine["hostname"]}'
-        )
+        dx_logging.print_info(f'Waiting for jobs on : {engine["hostname"]}')
     while engine_running_jobs:
         for j in engine_running_jobs:
             job_obj = job.get(dx_obj.server_session, j)
@@ -208,11 +221,11 @@ def track_running_jobs(
             elif job_obj.job_state in ["CANCELED", "FAILED"]:
                 err_msg = extract_failure_message(job_obj)
                 engine_running_jobs.remove(j)
-                dx_logging.print_info(
+                dx_logging.print_exception(
                     f'Engine: {engine["hostname"]}: {job_obj.reference} was CANCELLED or FAILED '
                     f"due to an error"
                 )
-                dx_logging.print_info(f"{err_msg}")
+                dx_logging.print_exception(f"{err_msg}")
                 failures[0] = True
                 raise Exception(f"{job_obj.job_id} {job_obj.job_state}")
 
