@@ -1,25 +1,6 @@
 #
 # Copyright (c) 2021 by Delphix. All rights reserved.
 #
-"""
-Examples:
-  dx_environment.py --list
-  dx_environment.py --create --engine mymask --os_type Linux
-  --env_name oratgt --host_user delphix --passwd xxxx
-  --ip 10.0.1.30 --toolkit /home/delphix
-  dx_environment.py --create --engine mymask --os_type Windows
-  --env_name wintgt --host_user delphix\dephix_trgt
-  --passwd xxxx --ip 10.0.1.60 --connector_host_name wintgt
-  dx_environment.py --create --os_type Windows --env_name winsrc
-  --host_user delphix\delphix_src --passwd delphix
-  --ip 10.0.1.50 --connector_host_name wintgt
-  dx_environment.py --enable --engine mymask --env_name oratgt
-  dx_environment.py --disable --engine mymask --env_name oratgt
-  dx_environment.py --refresh --engine mymask --env_name oratgt
-  dx_environment.py --delete --engine mymask --env_name oratgt
-  dx_environment.py --update_host --engine mymask
-  --old_host_address 10.0.1.20 --new_host_address 10.0.1.30
-"""
 
 from delphixpy.v1_10_2 import exceptions
 from delphixpy.v1_10_2.web import environment
@@ -34,6 +15,7 @@ from dxi._lib.dxi_constants import EnvironmentTypes
 from dxi._lib.dxi_constants import HostTypes
 from dxi._lib.run_async import run_async
 from dxi.dxi_tool_base import DXIBase
+from tabulate import tabulate
 
 
 class EnvironmentConstants(object):
@@ -51,6 +33,14 @@ class EnvironmentConstants(object):
     ACTION = None
     HOSTIP = None
     MODULE_NAME = __name__
+    LIST_HEADER = [
+        "Env Name",
+        "Env Type",
+        "Env IP",
+        "Enabled",
+        "Env User",
+        "ASE DB User",
+    ]
 
 
 class DXIEnvironment(DXIBase):
@@ -206,11 +196,11 @@ class DXIEnvironment(DXIBase):
         env_type=EnvironmentConstants.TYPE,
         host_ip=EnvironmentConstants.HOSTIP,
         toolkit_dir=None,
-        username=None,
-        password=None,
+        os_user=None,
+        os_user_pwd=None,
         connector_env_name=None,
-        ase_db_username=None,
-        ase_db_password=None,
+        ase_db_user=None,
+        ase_db_user_pwd=None,
     ):
         """
         :param env_name: Name of the environment in Delphix
@@ -235,14 +225,16 @@ class DXIEnvironment(DXIBase):
         self.env_type = env_type
         self.host_ip = host_ip
         self.toolkit_dir = toolkit_dir
-        self.username = username
-        self.password = password
+        self.username = os_user
+        self.password = os_user_pwd
         self.connector_env_name = connector_env_name
-        self.ase_db_username = ase_db_username
-        self.ase_db_password = ase_db_password
+        self.ase_db_username = ase_db_user
+        self.ase_db_password = ase_db_user_pwd
         try:
             self._environment_execution_helper()
-            dx_logging.print_debug("End of Execution")
+            dx_logging.print_debug(
+                "Adding environment to Delphix Engine complete."
+            )
             return True
         except Exception as err:
             dx_logging.print_exception(
@@ -429,6 +421,9 @@ class DXIEnvironment(DXIBase):
             )
             return
         env_host = ""
+        ase_params = ""
+        print_list = []
+        env_list = []
         for env in all_envs:
             env_user = get_references.find_obj_name(
                 dlpx_obj.server_session, environment.user, env.primary_user
@@ -439,23 +434,52 @@ class DXIEnvironment(DXIBase):
                 )
             except AttributeError:
                 pass
-            if env.type == "WindowsHostEnvironment":
-                print(
-                    f"Environment Name: {env.name}, Username: {env_user}, "
-                    f"Host: {env_host},Enabled: {env.enabled}"
+            try:
+                if hasattr(env, "env.ase_host_environment_parameters"):
+                    if isinstance(
+                        env.env.ase_host_environment_parameters,
+                        vo.ASEHostEnvironmentParameters,
+                    ):
+                        ase_params = (
+                            env.env.ase_host_environment_parameters.db_user
+                        )
+            except Exception:
+                dx_logging.print_exception(
+                    "Exception retrieving ASE env info."
                 )
-            elif env.type == "WindowsCluster" or env.type == "OracleCluster":
-                print(
-                    f"Environment Name: {env.name}, Username: {env_user}"
-                    f"Enabled: {env.enabled}, "
-                )
-            else:
-                print(
-                    f"Environment Name: {env.name}, Username: {env_user}, "
-                    f"Host: {env_host}, Enabled: {env.enabled}, "
-                    f"ASE Environment Params: "
-                    f'{env.ase_host_environment_parameters if isinstance(env.ase_host_environment_parameters,vo.ASEHostEnvironmentParameters) else "Undefined"}'  # noqa
+            print_list.append(
+                [
+                    env.name,
+                    env.type,
+                    env_host,
+                    env.enabled,
+                    env_user,
+                    ase_params,
+                ]
+            )
+            env_list.append(
+                dict(
+                    zip(
+                        EnvironmentConstants.LIST_HEADER,
+                        [
+                            env.name,
+                            env_user,
+                            env_host,
+                            env.enabled,
+                            env_user,
+                            ase_params,
+                        ],
+                    )
                 )
+            )
+        print(
+            tabulate(
+                print_list,
+                headers=EnvironmentConstants.LIST_HEADER,
+                tablefmt="grid",
+            )
+        )
+        return env_list
 
     def _delete_env(self, dlpx_obj):
         """
@@ -540,6 +564,7 @@ class DXIEnvironment(DXIBase):
         # setting user credentials
         env_params_obj.primary_user = vo.EnvironmentUser()
         env_params_obj.primary_user.name = self.username
+
         if self.password is None:
             env_params_obj.primary_user.credential = vo.SystemKeyCredential()
         else:
@@ -650,7 +675,7 @@ class DXIEnvironment(DXIBase):
                 if self.action == EnvironmentOps.LIST:
                     self._list_env(dlpx_obj)
                 elif self.action == EnvironmentOps.ADD:
-                    if self.env_type.lower() == EnvironmentTypes.WIN:
+                    if self.env_type.lower() == EnvironmentTypes.WIN.value:
                         self._add_windows_env(dlpx_obj)
                     else:
                         self._add_linux_env(dlpx_obj)
