@@ -42,7 +42,7 @@ class DXISnapshot(DXIBase):
 
     def __init__(
         self,
-        name=SnapshotConstants.NAME,
+        db_name=SnapshotConstants.NAME,
         group=SnapshotConstants.GROUP,
         parallel=SnapshotConstants.PARALLEL,
         engine=SnapshotConstants.ENGINE_ID,
@@ -53,9 +53,9 @@ class DXISnapshot(DXIBase):
         single_thread=SnapshotConstants.SINGLE_THREAD,
     ):
         """
-        :param name: Name of object in Delphix to refresh against
+        :param name: Name of object in Delphix to snapshot against
         :type name: `str`
-        :param group: Name of group in Delphix to refresh against.
+        :param group: Name of group in Delphix to snapshot against.
         :type group: `str`
         :param parallel: Limit number of jobs to maxjob
         :type parallel: `int`
@@ -83,7 +83,7 @@ class DXISnapshot(DXIBase):
             module_name=__name__,
         )
         self.all_dbs = all_dbs
-        self.name = name
+        self.name = db_name
         self.group = group
         self.use_backup = SnapshotConstants.USE_BACKUP
         self.create_bckup = SnapshotConstants.CREATE_BACKUP
@@ -110,22 +110,22 @@ class DXISnapshot(DXIBase):
             raise
 
     def create_snapshot(
-        self, usebackup=False, create_bckup=False, bck_file=None
+        self, use_recent_backup=False, create_backup=False, backup_file=None
     ):
         """
-        :param usebackup: Snapshot using "Most Recent backup".
-        :type usebackup: `bool`
-        :param create_bckup:
+        :param use_recent_backup: Snapshot using "Most Recent backup".
+        :type use_recent_backup: `bool`
+        :param create_backup:
             Create and ingest a new Sybase backup or copy-only MS SQL backup
-        :type create_bckup: `bool`
-        :param bck_file: Name of the specific ASE Sybase backup file(s)
-        :type bck_file: `str`
+        :type create_backup: `bool`
+        :param backup_file: Name of the specific ASE Sybase backup file(s)
+        :type backup_file: `str`
         :returns: Snapshot creation status
         :rtype: `bool`
         """
-        self.use_backup = usebackup
-        self.create_bckup = create_bckup
-        self.bck_file = bck_file
+        self.use_backup = use_recent_backup
+        self.create_bckup = create_backup
+        self.bck_file = backup_file
         try:
             self._execute_operation(self._create_snapshot_helper)
             return True
@@ -189,15 +189,15 @@ class DXISnapshot(DXIBase):
                 # so we will omit any extra code to check
                 elif db_source_info.type == "ASELinkedSource":
                     if self.use_backup is True:
-                        if self.bck_file:
-                            sync_params = vo.ASESpecificBackupSyncParameters()
-                            sync_params.backup_files = self.bck_file.split(" ")
-                        elif self.create_bckup:
-                            sync_params = vo.ASENewBackupSyncParameters()
-                        else:
-                            sync_params = vo.ASELatestBackupSyncParameters()
+                        sync_params = vo.ASELatestBackupSyncParameters()
+                    elif self.bck_file:
+                        sync_params = vo.ASESpecificBackupSyncParameters()
+                        sync_params.backup_files = self.bck_file.split(" ")
+                    elif self.create_bckup:
+                        sync_params = vo.ASENewBackupSyncParameters()
                     else:
                         sync_params = vo.ASENewBackupSyncParameters()
+
                 if sync_params:
                     database.sync(
                         dlpx_obj.server_session, container_obj_ref, sync_params
